function [FractionalChange, RatioChange, scenario_ResultsCompiled] = f_CompileScenarioResults_08192013(Production_base, Production_scenario, max_ScaleFactor)
% f_CompileScenarioResults is a simple function to compile base model to scenario model results
% J. Ruzicka
% takes:
%     Production_base
%     Production_scenario
%     max_ScaleFactor
% returns:
%     FractionalChange         scenario production change relative to base production (1 column for each MonteCarlo model)
%     RatioChange              ratio of scenario production base production (1 column for each MonteCarlo model)
%     scenario_ResultsCompiled
%                              clm 1: FractionalChange_mean
%                              clm 2: FractionalChange_std
%                              clm 3: RatioChange_mean 
%                              clm 4: RatioChange_std
%                              clm 5: Production_scenario_mean 
%                              clm 6: Production_scenario_std 
%                              clm 7: Production_base_mean 
%                              clm 8: Production_base_std
% calls:
%     none
% revision date: 8-19-2013




% *************************************************************************
% STEP 1: calculate (1) ratio of scenario-to-base and (2) scenario change relative to base
Production_scenario_mean                  = nanmean(Production_scenario, 2);
Production_scenario_std                   = nanstd(Production_scenario, 2); % if error caused by nan function, try this ---> nanstd(RatioChange, 0, 2)

Production_base_mean                      = nanmean(Production_base, 2);
Production_base_std                       = nanstd(Production_base, 2); % if error caused by nan function, try this ---> nanstd(RatioChange, 0, 2)

FractionalChange                          = ((Production_scenario - Production_base) ./ Production_base); % relative change in production
RatioChange                               = Production_scenario ./ Production_base;
FractionalChange(isnan(FractionalChange)) = 0; % correct for NaNs caused when Production_base = 0
RatioChange(isnan(RatioChange))           = 0; % correct for NaNs caused when Production_base = 0

RatioChange_mean                          = nanmean(RatioChange, 2);
RatioChange_std                           = nanstd(RatioChange, 2); % if error caused by nan function, try this ---> nanstd(RatioChange, 0, 2)

FractionalChange_mean                     = nanmean(FractionalChange, 2);
FractionalChange_std                      = nanstd(FractionalChange, 2); % if error caused by nan function, try this ---> nanstd(RatioChange, 0, 2)

mean_max_ScaleFactor                      = mean(max_ScaleFactor, 1);
std_max_ScaleFactor                       = std(max_ScaleFactor, 0, 1);

scenario_ResultsCompiled                  = [FractionalChange_mean FractionalChange_std RatioChange_mean RatioChange_std ...
                                             Production_scenario_mean Production_scenario_std Production_base_mean Production_base_std];

% end m-file***************************************************************