function WebProductivity = f_WebProductivityWLoss(TransferEfficiency, BottomUpMatrix, InputProductionVector, PhysicalLossFraction)
% based on John Steele code
% calculate web production rates given production input at bottom of web
% takes:
%       TransferEfficiency          (dimensionless)                     (horizontal vector)
%       BottomUpMatrix              (dimensionless)                     (matrix)
%       InputProductionVector       (biomass density / time)            (horizontal vector)
%       PhysicalLossFraction        (loss fraction of production)       (horizontal vector)
% returns:
%       WebProductivity             (biomass density / time)            (vertical vector)
% revision date: 4-7-10

inverted_TransferEfficiency = (1 + PhysicalLossFraction) ./ TransferEfficiency;

K = diag(inverted_TransferEfficiency, 0);
WebProductivity = inv(K-BottomUpMatrix) * InputProductionVector'; % production rates

% end function*********************************************************